/**
 * Base64 Encoder
 *
 * Other than the decoder, the encoder does not work chunkwise.
 * To simulate chunkwise encoding, split the data source in multiples of 3 bytes
 * and concat the output afterwards.
 *
 * The implementation uses a 16-bit LUT to map 12 input bits to 2 base64 digits
 * roughly doubling the throughput compared to a simple scalar implementation.
 */
export default class Base64Encoder {
    keepSize: number;
    private _inst;
    private _mem;
    private _d;
    constructor(keepSize: number);
    /**
     * Encode bytes in `d` as base64.
     * Returns encoded byte array (borrowed).
     */
    encode(d: Uint8Array): Uint8Array;
    /**
     * Release memory conditionally based on `keepSize`.
     * If memory gets released, also the wasm instance will be freed and recreated on next `encode`,
     * otherwise the instance will be reused.
     */
    release(): void;
}
